package com.qmth.teachcloud.cas.mq.gdpu.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.teachcloud.exchange.common.bean.dto.flow.DoneTaskDto;
import com.qmth.teachcloud.exchange.common.bean.dto.flow.ToDoTaskDto;
import com.qmth.teachcloud.exchange.common.contant.SystemConstant;
import com.qmth.teachcloud.exchange.common.entity.BasicSchool;
import com.qmth.teachcloud.exchange.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.exchange.common.util.AuthThirdUtil;
import com.qmth.teachcloud.exchange.common.util.JacksonUtil;
import com.qmth.teachcloud.exchange.common.util.Result;
import com.qmth.teachcloud.exchange.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.net.URLDecoder;
import java.util.Optional;

@Api(tags = "广东药科大学获取流程消息controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_GDPU_MQ)
@Aac(auth = BOOL.FALSE)
@Validated
public class OpenMqController {
    private final static Logger log = LoggerFactory.getLogger(OpenMqController.class);

    @RequestMapping(value = "/{schoolCode}/todotask", method = RequestMethod.POST)
    @ApiOperation(value = "获取流程待办信息")
    @ApiResponses({@ApiResponse(code = 200, message = "常规信息", response = ResultUtil.class)})
    public Result toDoTask(@ApiParam(value = "学校编码") @PathVariable("schoolCode") String schoolCode,
                           @ApiParam(value = "消息数据", required = true) @RequestBody String data) throws IOException {
        Optional.ofNullable(data).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("账号为空"));
        String decodeJson = URLDecoder.decode(data, SystemConstant.CHARSET_NAME);
        ToDoTaskDto toDoTaskDto = JacksonUtil.readJson(decodeJson, ToDoTaskDto.class);
        log.info("todotask进来了,toDoTaskDto:{}", JacksonUtil.parseJson(toDoTaskDto));

        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(true);
    }

    @RequestMapping(value = "/{schoolCode}/donetask", method = RequestMethod.POST)
    @ApiOperation(value = "获取流程已办信息")
    @ApiResponses({@ApiResponse(code = 200, message = "常规信息", response = ResultUtil.class)})
    public Result doneTask(@ApiParam(value = "学校编码") @PathVariable("schoolCode") String schoolCode,
                           @ApiParam(value = "消息数据", required = true) @RequestBody String data) throws IOException {
        Optional.ofNullable(data).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("账号为空"));
        String decodeJson = URLDecoder.decode(data, SystemConstant.CHARSET_NAME);
        DoneTaskDto doneTaskDto = JacksonUtil.readJson(decodeJson, DoneTaskDto.class);
        log.info("donetask进来了,doneTaskDto:{}", JacksonUtil.parseJson(doneTaskDto));

        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(true);
    }
}